# flake8: noqa

# import apis into api package
from daiedge_middleware_client.api.access_control_api import AccessControlApi
from daiedge_middleware_client.api.auth_api import AuthApi
from daiedge_middleware_client.api.identity_api import IdentityApi
from daiedge_middleware_client.api.license_api import LicenseApi
from daiedge_middleware_client.api.marketplace_api import MarketplaceApi
from daiedge_middleware_client.api.policy_api import PolicyApi
from daiedge_middleware_client.api.register_ai_model_api import RegisterAiModelApi
from daiedge_middleware_client.api.register_benchmark_api import RegisterBenchmarkApi
from daiedge_middleware_client.api.register_dataset_api import RegisterDatasetApi
from daiedge_middleware_client.api.register_hardware_api import RegisterHardwareApi
from daiedge_middleware_client.api.reward_manager_api import RewardManagerApi
from daiedge_middleware_client.api.role_management_api import RoleManagementApi
from daiedge_middleware_client.api.system_pause_api import SystemPauseApi
from daiedge_middleware_client.api.tokens_api import TokensApi
from daiedge_middleware_client.api.users_api import UsersApi
from daiedge_middleware_client.api.vc_api import VcApi
from daiedge_middleware_client.api.wallet_api import WalletApi




# coding: utf-8

"""
    dAIEDGE-DLT

    API documentation

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from daiedge_middleware_client.models.cpu import CPU

class TestCPU(unittest.TestCase):
    """CPU unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CPU:
        """Test CPU
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CPU`
        """
        model = CPU()
        if include_optional:
            return CPU(
                id = '',
                arch = '',
                model = '',
                specs = daiedge_middleware_client.models.cpu_specs_item.CPUSpecsItem(
                    rate = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                        value = 1.337, 
                        unit = '', 
                        kind = '', ), 
                    cores = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                        value = 1.337, 
                        unit = '', 
                        kind = '', ), 
                    computing_power = , )
            )
        else:
            return CPU(
                id = '',
                arch = '',
                model = '',
                specs = daiedge_middleware_client.models.cpu_specs_item.CPUSpecsItem(
                    rate = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                        value = 1.337, 
                        unit = '', 
                        kind = '', ), 
                    cores = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                        value = 1.337, 
                        unit = '', 
                        kind = '', ), 
                    computing_power = , ),
        )
        """

    def testCPU(self):
        """Test CPU"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
dAIEDGE-DLT

API documentation

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.2"

# Define package exports
__all__ = [
    "AccessControlApi",
    "AuthApi",
    "IdentityApi",
    "LicenseApi",
    "MarketplaceApi",
    "PolicyApi",
    "RegisterAiModelApi",
    "RegisterBenchmarkApi",
    "RegisterDatasetApi",
    "RegisterHardwareApi",
    "RewardManagerApi",
    "RoleManagementApi",
    "SystemPauseApi",
    "TokensApi",
    "UsersApi",
    "VcApi",
    "WalletApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "Accelerator",
    "AcceptVCRequestBody",
    "AddDelegateBody",
    "AuthenticationContext",
    "AuthenticationContextError",
    "BuyResourceBody",
    "CPU",
    "CPUSpecsItem",
    "ChangeOwnerBody",
    "CheckAccessResponse",
    "Cost",
    "CreateAIModelResponse",
    "CreateBenchmarkResponse",
    "CreateDIDPolicyBody",
    "CreateDatasetResponse",
    "CreateHardwarePolicyBody",
    "CreateHardwareResponse",
    "CreateRoleBody",
    "CreateRoleResponse",
    "DecodeCredentialBody",
    "DefaultSpecItem",
    "DefaultSpecsMemory",
    "DeleteHardwareBody",
    "EditDIDPolicyBody",
    "EditHardwarePolicyBody",
    "Engine",
    "ErrorResponse",
    "GenerateKeyPairBody",
    "GetRegisterAIModelItem",
    "GetRegisterBenchmarkItem",
    "GetRegisterDatasetItem",
    "GetRegisterHardwareItem",
    "GetRewardByRule",
    "GranRoleBody",
    "GrantAccessBody",
    "GrantRevokeIssuerRoleBody",
    "HardwareAccessItem",
    "HardwareAccessList",
    "HardwarePolicyResponse",
    "HardwareSpec",
    "HasRoleResponse",
    "IdentityOwnerResponse",
    "LicenseRequestItem",
    "LicenseRequestList",
    "ListedResourceItem",
    "ListedResourceList",
    "LoginErrorBadRequest",
    "LoginErrorForbidden",
    "LoginRequest",
    "LoginResponse",
    "Memory",
    "MintTokensBody",
    "PauseContractBody",
    "PauseSystemBody",
    "Power",
    "PowerItemDetails",
    "RegisterAIModelBody",
    "RegisterAIModelItem",
    "RegisterAIModelList",
    "RegisterAccessBody",
    "RegisterBenchmarkBody",
    "RegisterBenchmarkItem",
    "RegisterBenchmarkList",
    "RegisterDataSetItem",
    "RegisterDataSetList",
    "RegisterDatasetBody",
    "RegisterHardwareBody",
    "RegisterHardwareItem",
    "RegisterHardwareList",
    "RemoveDIDPolicyBody",
    "RemoveHardwarePolicyBody",
    "RemoveListedResourceBody",
    "RemoveRewardRuleBody",
    "RequestUserLicenseBody",
    "RequestVCBody",
    "RevokeAccessBody",
    "RevokeDelegateBody",
    "RevokeIssuerRoleBody",
    "RevokeLicenseBody",
    "RevokeRoleBody",
    "RewardHistoryItem",
    "RewardHistoryList",
    "RewardManualBody",
    "RewardOffChainBody",
    "RewardOnChainBody",
    "RoleManagementItem",
    "RoleManagementList",
    "SellResourceBody",
    "SetBenchmarkResultBody",
    "SetHardwareBody",
    "SetRewardRuleBody",
    "SignupErrorBadRequest",
    "SignupRequest",
    "SignupResponse",
    "SoftwareSpec",
    "Storage",
    "StorageSpecsItem",
    "SupportedApplication",
    "SupportedApplicationDetails",
    "SystemStatus",
    "UnpauseContractBody",
    "UnpauseSystemBody",
    "UpdateAIModelBody",
    "UpdateDatasetBody",
    "UpdateHardwareBody",
    "UseLicenseItem",
    "UserDIDItem",
    "UserDIDList",
    "UserDIDResolveResponse",
    "UserLicenseList",
    "UserVCItem",
    "UserVCList",
    "VCClaim",
    "VCRequestItem",
    "VCRequestList",
    "ValidateLicenseRequestBody",
    "VerifyCredentialBody",
    "VerifyCredentialResponse",
    "VerifyPresentationBody",
    "WalletChangePasswordBadRequest",
    "WalletChangePasswordBody",
    "WalletCreateBadRequest",
    "WalletCreateBody",
    "WalletEditBadRequest",
    "WalletEditBody",
    "WalletExportBadRequest",
    "WalletExportBody",
    "WalletExportResponse",
    "WalletInfo",
]

# import apis into sdk package
from daiedge_middleware_client.api.access_control_api import (
    AccessControlApi as AccessControlApi,
)
from daiedge_middleware_client.api.auth_api import AuthApi as AuthApi
from daiedge_middleware_client.api.identity_api import IdentityApi as IdentityApi
from daiedge_middleware_client.api.license_api import LicenseApi as LicenseApi
from daiedge_middleware_client.api.marketplace_api import (
    MarketplaceApi as MarketplaceApi,
)
from daiedge_middleware_client.api.policy_api import PolicyApi as PolicyApi
from daiedge_middleware_client.api.register_ai_model_api import (
    RegisterAiModelApi as RegisterAiModelApi,
)
from daiedge_middleware_client.api.register_benchmark_api import (
    RegisterBenchmarkApi as RegisterBenchmarkApi,
)
from daiedge_middleware_client.api.register_dataset_api import (
    RegisterDatasetApi as RegisterDatasetApi,
)
from daiedge_middleware_client.api.register_hardware_api import (
    RegisterHardwareApi as RegisterHardwareApi,
)
from daiedge_middleware_client.api.reward_manager_api import (
    RewardManagerApi as RewardManagerApi,
)
from daiedge_middleware_client.api.role_management_api import (
    RoleManagementApi as RoleManagementApi,
)
from daiedge_middleware_client.api.system_pause_api import (
    SystemPauseApi as SystemPauseApi,
)
from daiedge_middleware_client.api.tokens_api import TokensApi as TokensApi
from daiedge_middleware_client.api.users_api import UsersApi as UsersApi
from daiedge_middleware_client.api.vc_api import VcApi as VcApi
from daiedge_middleware_client.api.wallet_api import WalletApi as WalletApi

# import ApiClient
from daiedge_middleware_client.api_response import ApiResponse as ApiResponse
from daiedge_middleware_client.api_client import ApiClient as ApiClient
from daiedge_middleware_client.configuration import Configuration as Configuration
from daiedge_middleware_client.exceptions import OpenApiException as OpenApiException
from daiedge_middleware_client.exceptions import ApiTypeError as ApiTypeError
from daiedge_middleware_client.exceptions import ApiValueError as ApiValueError
from daiedge_middleware_client.exceptions import ApiKeyError as ApiKeyError
from daiedge_middleware_client.exceptions import ApiAttributeError as ApiAttributeError
from daiedge_middleware_client.exceptions import ApiException as ApiException

# import models into sdk package
from daiedge_middleware_client.models.accelerator import Accelerator as Accelerator
from daiedge_middleware_client.models.accept_vc_request_body import (
    AcceptVCRequestBody as AcceptVCRequestBody,
)
from daiedge_middleware_client.models.add_delegate_body import (
    AddDelegateBody as AddDelegateBody,
)
from daiedge_middleware_client.models.authentication_context import (
    AuthenticationContext as AuthenticationContext,
)
from daiedge_middleware_client.models.authentication_context_error import (
    AuthenticationContextError as AuthenticationContextError,
)
from daiedge_middleware_client.models.buy_resource_body import (
    BuyResourceBody as BuyResourceBody,
)
from daiedge_middleware_client.models.cpu import CPU as CPU
from daiedge_middleware_client.models.cpu_specs_item import CPUSpecsItem as CPUSpecsItem
from daiedge_middleware_client.models.change_owner_body import (
    ChangeOwnerBody as ChangeOwnerBody,
)
from daiedge_middleware_client.models.check_access_response import (
    CheckAccessResponse as CheckAccessResponse,
)
from daiedge_middleware_client.models.cost import Cost as Cost
from daiedge_middleware_client.models.create_ai_model_response import (
    CreateAIModelResponse as CreateAIModelResponse,
)
from daiedge_middleware_client.models.create_benchmark_response import (
    CreateBenchmarkResponse as CreateBenchmarkResponse,
)
from daiedge_middleware_client.models.create_did_policy_body import (
    CreateDIDPolicyBody as CreateDIDPolicyBody,
)
from daiedge_middleware_client.models.create_dataset_response import (
    CreateDatasetResponse as CreateDatasetResponse,
)
from daiedge_middleware_client.models.create_hardware_policy_body import (
    CreateHardwarePolicyBody as CreateHardwarePolicyBody,
)
from daiedge_middleware_client.models.create_hardware_response import (
    CreateHardwareResponse as CreateHardwareResponse,
)
from daiedge_middleware_client.models.create_role_body import (
    CreateRoleBody as CreateRoleBody,
)
from daiedge_middleware_client.models.create_role_response import (
    CreateRoleResponse as CreateRoleResponse,
)
from daiedge_middleware_client.models.decode_credential_body import (
    DecodeCredentialBody as DecodeCredentialBody,
)
from daiedge_middleware_client.models.default_spec_item import (
    DefaultSpecItem as DefaultSpecItem,
)
from daiedge_middleware_client.models.default_specs_memory import (
    DefaultSpecsMemory as DefaultSpecsMemory,
)
from daiedge_middleware_client.models.delete_hardware_body import (
    DeleteHardwareBody as DeleteHardwareBody,
)
from daiedge_middleware_client.models.edit_did_policy_body import (
    EditDIDPolicyBody as EditDIDPolicyBody,
)
from daiedge_middleware_client.models.edit_hardware_policy_body import (
    EditHardwarePolicyBody as EditHardwarePolicyBody,
)
from daiedge_middleware_client.models.engine import Engine as Engine
from daiedge_middleware_client.models.error_response import (
    ErrorResponse as ErrorResponse,
)
from daiedge_middleware_client.models.generate_key_pair_body import (
    GenerateKeyPairBody as GenerateKeyPairBody,
)
from daiedge_middleware_client.models.get_register_ai_model_item import (
    GetRegisterAIModelItem as GetRegisterAIModelItem,
)
from daiedge_middleware_client.models.get_register_benchmark_item import (
    GetRegisterBenchmarkItem as GetRegisterBenchmarkItem,
)
from daiedge_middleware_client.models.get_register_dataset_item import (
    GetRegisterDatasetItem as GetRegisterDatasetItem,
)
from daiedge_middleware_client.models.get_register_hardware_item import (
    GetRegisterHardwareItem as GetRegisterHardwareItem,
)
from daiedge_middleware_client.models.get_reward_by_rule import (
    GetRewardByRule as GetRewardByRule,
)
from daiedge_middleware_client.models.gran_role_body import GranRoleBody as GranRoleBody
from daiedge_middleware_client.models.grant_access_body import (
    GrantAccessBody as GrantAccessBody,
)
from daiedge_middleware_client.models.grant_revoke_issuer_role_body import (
    GrantRevokeIssuerRoleBody as GrantRevokeIssuerRoleBody,
)
from daiedge_middleware_client.models.hardware_access_item import (
    HardwareAccessItem as HardwareAccessItem,
)
from daiedge_middleware_client.models.hardware_access_list import (
    HardwareAccessList as HardwareAccessList,
)
from daiedge_middleware_client.models.hardware_policy_response import (
    HardwarePolicyResponse as HardwarePolicyResponse,
)
from daiedge_middleware_client.models.hardware_spec import HardwareSpec as HardwareSpec
from daiedge_middleware_client.models.has_role_response import (
    HasRoleResponse as HasRoleResponse,
)
from daiedge_middleware_client.models.identity_owner_response import (
    IdentityOwnerResponse as IdentityOwnerResponse,
)
from daiedge_middleware_client.models.license_request_item import (
    LicenseRequestItem as LicenseRequestItem,
)
from daiedge_middleware_client.models.license_request_list import (
    LicenseRequestList as LicenseRequestList,
)
from daiedge_middleware_client.models.listed_resource_item import (
    ListedResourceItem as ListedResourceItem,
)
from daiedge_middleware_client.models.listed_resource_list import (
    ListedResourceList as ListedResourceList,
)
from daiedge_middleware_client.models.login_error_bad_request import (
    LoginErrorBadRequest as LoginErrorBadRequest,
)
from daiedge_middleware_client.models.login_error_forbidden import (
    LoginErrorForbidden as LoginErrorForbidden,
)
from daiedge_middleware_client.models.login_request import LoginRequest as LoginRequest
from daiedge_middleware_client.models.login_response import (
    LoginResponse as LoginResponse,
)
from daiedge_middleware_client.models.memory import Memory as Memory
from daiedge_middleware_client.models.mint_tokens_body import (
    MintTokensBody as MintTokensBody,
)
from daiedge_middleware_client.models.pause_contract_body import (
    PauseContractBody as PauseContractBody,
)
from daiedge_middleware_client.models.pause_system_body import (
    PauseSystemBody as PauseSystemBody,
)
from daiedge_middleware_client.models.power import Power as Power
from daiedge_middleware_client.models.power_item_details import (
    PowerItemDetails as PowerItemDetails,
)
from daiedge_middleware_client.models.register_ai_model_body import (
    RegisterAIModelBody as RegisterAIModelBody,
)
from daiedge_middleware_client.models.register_ai_model_item import (
    RegisterAIModelItem as RegisterAIModelItem,
)
from daiedge_middleware_client.models.register_ai_model_list import (
    RegisterAIModelList as RegisterAIModelList,
)
from daiedge_middleware_client.models.register_access_body import (
    RegisterAccessBody as RegisterAccessBody,
)
from daiedge_middleware_client.models.register_benchmark_body import (
    RegisterBenchmarkBody as RegisterBenchmarkBody,
)
from daiedge_middleware_client.models.register_benchmark_item import (
    RegisterBenchmarkItem as RegisterBenchmarkItem,
)
from daiedge_middleware_client.models.register_benchmark_list import (
    RegisterBenchmarkList as RegisterBenchmarkList,
)
from daiedge_middleware_client.models.register_data_set_item import (
    RegisterDataSetItem as RegisterDataSetItem,
)
from daiedge_middleware_client.models.register_data_set_list import (
    RegisterDataSetList as RegisterDataSetList,
)
from daiedge_middleware_client.models.register_dataset_body import (
    RegisterDatasetBody as RegisterDatasetBody,
)
from daiedge_middleware_client.models.register_hardware_body import (
    RegisterHardwareBody as RegisterHardwareBody,
)
from daiedge_middleware_client.models.register_hardware_item import (
    RegisterHardwareItem as RegisterHardwareItem,
)
from daiedge_middleware_client.models.register_hardware_list import (
    RegisterHardwareList as RegisterHardwareList,
)
from daiedge_middleware_client.models.remove_did_policy_body import (
    RemoveDIDPolicyBody as RemoveDIDPolicyBody,
)
from daiedge_middleware_client.models.remove_hardware_policy_body import (
    RemoveHardwarePolicyBody as RemoveHardwarePolicyBody,
)
from daiedge_middleware_client.models.remove_listed_resource_body import (
    RemoveListedResourceBody as RemoveListedResourceBody,
)
from daiedge_middleware_client.models.remove_reward_rule_body import (
    RemoveRewardRuleBody as RemoveRewardRuleBody,
)
from daiedge_middleware_client.models.request_user_license_body import (
    RequestUserLicenseBody as RequestUserLicenseBody,
)
from daiedge_middleware_client.models.request_vc_body import (
    RequestVCBody as RequestVCBody,
)
from daiedge_middleware_client.models.revoke_access_body import (
    RevokeAccessBody as RevokeAccessBody,
)
from daiedge_middleware_client.models.revoke_delegate_body import (
    RevokeDelegateBody as RevokeDelegateBody,
)
from daiedge_middleware_client.models.revoke_issuer_role_body import (
    RevokeIssuerRoleBody as RevokeIssuerRoleBody,
)
from daiedge_middleware_client.models.revoke_license_body import (
    RevokeLicenseBody as RevokeLicenseBody,
)
from daiedge_middleware_client.models.revoke_role_body import (
    RevokeRoleBody as RevokeRoleBody,
)
from daiedge_middleware_client.models.reward_history_item import (
    RewardHistoryItem as RewardHistoryItem,
)
from daiedge_middleware_client.models.reward_history_list import (
    RewardHistoryList as RewardHistoryList,
)
from daiedge_middleware_client.models.reward_manual_body import (
    RewardManualBody as RewardManualBody,
)
from daiedge_middleware_client.models.reward_off_chain_body import (
    RewardOffChainBody as RewardOffChainBody,
)
from daiedge_middleware_client.models.reward_on_chain_body import (
    RewardOnChainBody as RewardOnChainBody,
)
from daiedge_middleware_client.models.role_management_item import (
    RoleManagementItem as RoleManagementItem,
)
from daiedge_middleware_client.models.role_management_list import (
    RoleManagementList as RoleManagementList,
)
from daiedge_middleware_client.models.sell_resource_body import (
    SellResourceBody as SellResourceBody,
)
from daiedge_middleware_client.models.set_benchmark_result_body import (
    SetBenchmarkResultBody as SetBenchmarkResultBody,
)
from daiedge_middleware_client.models.set_hardware_body import (
    SetHardwareBody as SetHardwareBody,
)
from daiedge_middleware_client.models.set_reward_rule_body import (
    SetRewardRuleBody as SetRewardRuleBody,
)
from daiedge_middleware_client.models.signup_error_bad_request import (
    SignupErrorBadRequest as SignupErrorBadRequest,
)
from daiedge_middleware_client.models.signup_request import (
    SignupRequest as SignupRequest,
)
from daiedge_middleware_client.models.signup_response import (
    SignupResponse as SignupResponse,
)
from daiedge_middleware_client.models.software_spec import SoftwareSpec as SoftwareSpec
from daiedge_middleware_client.models.storage import Storage as Storage
from daiedge_middleware_client.models.storage_specs_item import (
    StorageSpecsItem as StorageSpecsItem,
)
from daiedge_middleware_client.models.supported_application import (
    SupportedApplication as SupportedApplication,
)
from daiedge_middleware_client.models.supported_application_details import (
    SupportedApplicationDetails as SupportedApplicationDetails,
)
from daiedge_middleware_client.models.system_status import SystemStatus as SystemStatus
from daiedge_middleware_client.models.unpause_contract_body import (
    UnpauseContractBody as UnpauseContractBody,
)
from daiedge_middleware_client.models.unpause_system_body import (
    UnpauseSystemBody as UnpauseSystemBody,
)
from daiedge_middleware_client.models.update_ai_model_body import (
    UpdateAIModelBody as UpdateAIModelBody,
)
from daiedge_middleware_client.models.update_dataset_body import (
    UpdateDatasetBody as UpdateDatasetBody,
)
from daiedge_middleware_client.models.update_hardware_body import (
    UpdateHardwareBody as UpdateHardwareBody,
)
from daiedge_middleware_client.models.use_license_item import (
    UseLicenseItem as UseLicenseItem,
)
from daiedge_middleware_client.models.user_did_item import UserDIDItem as UserDIDItem
from daiedge_middleware_client.models.user_did_list import UserDIDList as UserDIDList
from daiedge_middleware_client.models.user_did_resolve_response import (
    UserDIDResolveResponse as UserDIDResolveResponse,
)
from daiedge_middleware_client.models.user_license_list import (
    UserLicenseList as UserLicenseList,
)
from daiedge_middleware_client.models.user_vc_item import UserVCItem as UserVCItem
from daiedge_middleware_client.models.user_vc_list import UserVCList as UserVCList
from daiedge_middleware_client.models.vc_claim import VCClaim as VCClaim
from daiedge_middleware_client.models.vc_request_item import (
    VCRequestItem as VCRequestItem,
)
from daiedge_middleware_client.models.vc_request_list import (
    VCRequestList as VCRequestList,
)
from daiedge_middleware_client.models.validate_license_request_body import (
    ValidateLicenseRequestBody as ValidateLicenseRequestBody,
)
from daiedge_middleware_client.models.verify_credential_body import (
    VerifyCredentialBody as VerifyCredentialBody,
)
from daiedge_middleware_client.models.verify_credential_response import (
    VerifyCredentialResponse as VerifyCredentialResponse,
)
from daiedge_middleware_client.models.verify_presentation_body import (
    VerifyPresentationBody as VerifyPresentationBody,
)
from daiedge_middleware_client.models.wallet_change_password_bad_request import (
    WalletChangePasswordBadRequest as WalletChangePasswordBadRequest,
)
from daiedge_middleware_client.models.wallet_change_password_body import (
    WalletChangePasswordBody as WalletChangePasswordBody,
)
from daiedge_middleware_client.models.wallet_create_bad_request import (
    WalletCreateBadRequest as WalletCreateBadRequest,
)
from daiedge_middleware_client.models.wallet_create_body import (
    WalletCreateBody as WalletCreateBody,
)
from daiedge_middleware_client.models.wallet_edit_bad_request import (
    WalletEditBadRequest as WalletEditBadRequest,
)
from daiedge_middleware_client.models.wallet_edit_body import (
    WalletEditBody as WalletEditBody,
)
from daiedge_middleware_client.models.wallet_export_bad_request import (
    WalletExportBadRequest as WalletExportBadRequest,
)
from daiedge_middleware_client.models.wallet_export_body import (
    WalletExportBody as WalletExportBody,
)
from daiedge_middleware_client.models.wallet_export_response import (
    WalletExportResponse as WalletExportResponse,
)
from daiedge_middleware_client.models.wallet_info import WalletInfo as WalletInfo



# coding: utf-8

"""
    dAIEDGE-DLT

    API documentation

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from daiedge_middleware_client.models.update_hardware_body import UpdateHardwareBody

class TestUpdateHardwareBody(unittest.TestCase):
    """UpdateHardwareBody unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UpdateHardwareBody:
        """Test UpdateHardwareBody
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UpdateHardwareBody`
        """
        model = UpdateHardwareBody()
        if include_optional:
            return UpdateHardwareBody(
                wallet_id = '',
                password = '',
                did = '',
                is_implemented = True,
                description = '',
                family = '',
                hardware_spec = daiedge_middleware_client.models.hardware_spec.HardwareSpec(
                    cost = daiedge_middleware_client.models.cost.Cost(
                        value = 1.337, 
                        currency = '', 
                        unit = '', ), 
                    cpus = [
                        daiedge_middleware_client.models.cpu.CPU(
                            id = '', 
                            arch = '', 
                            model = '', 
                            specs = daiedge_middleware_client.models.cpu_specs_item.CPUSpecsItem(
                                rate = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                                    value = 1.337, 
                                    unit = '', 
                                    kind = '', ), 
                                cores = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                                    value = 1.337, 
                                    unit = '', 
                                    kind = '', ), 
                                computing_power = , ), )
                        ], 
                    accelerators = [
                        daiedge_middleware_client.models.accelerator.Accelerator(
                            id = '', 
                            type = '', 
                            model = '', 
                            specs = daiedge_middleware_client.models.cpu_specs_item.CPUSpecsItem(
                                rate = , 
                                cores = , 
                                computing_power = , ), )
                        ], 
                    memory = daiedge_middleware_client.models.memory.Memory(
                        type = '', 
                        kind = '', 
                        specs = daiedge_middleware_client.models.default_specs_memory.DefaultSpecsMemory(
                            size = , 
                            rate = , ), ), 
                    storage = daiedge_middleware_client.models.storage.Storage(
                        type = '', 
                        specs = daiedge_middleware_client.models.storage_specs_item.StorageSpecsItem(
                            size = , 
                            rate = , ), ), 
                    power = daiedge_middleware_client.models.power.Power(
                        min = daiedge_middleware_client.models.power_item_details.PowerItemDetails(
                            value = 1.337, 
                            unit = '', ), 
                        max = daiedge_middleware_client.models.power_item_details.PowerItemDetails(
                            value = 1.337, 
                            unit = '', ), ), ),
                software_spec = daiedge_middleware_client.models.software_spec.SoftwareSpec(
                    os = '', 
                    version = '', 
                    engines = [
                        daiedge_middleware_client.models.engine.Engine(
                            id = '', 
                            name = '', 
                            family = '', 
                            version = '', 
                            computing_backends = [
                                ''
                                ], 
                            supported_applications = [
                                daiedge_middleware_client.models.supported_application.SupportedApplication(
                                    type = '', 
                                    details = daiedge_middleware_client.models.supported_application_details.SupportedApplicationDetails(
                                        supported_types = [
                                            ''
                                            ], ), )
                                ], )
                        ], )
            )
        else:
            return UpdateHardwareBody(
                wallet_id = '',
                password = '',
                did = '',
                is_implemented = True,
                description = '',
                family = '',
                hardware_spec = daiedge_middleware_client.models.hardware_spec.HardwareSpec(
                    cost = daiedge_middleware_client.models.cost.Cost(
                        value = 1.337, 
                        currency = '', 
                        unit = '', ), 
                    cpus = [
                        daiedge_middleware_client.models.cpu.CPU(
                            id = '', 
                            arch = '', 
                            model = '', 
                            specs = daiedge_middleware_client.models.cpu_specs_item.CPUSpecsItem(
                                rate = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                                    value = 1.337, 
                                    unit = '', 
                                    kind = '', ), 
                                cores = daiedge_middleware_client.models.default_spec_item.DefaultSpecItem(
                                    value = 1.337, 
                                    unit = '', 
                                    kind = '', ), 
                                computing_power = , ), )
                        ], 
                    accelerators = [
                        daiedge_middleware_client.models.accelerator.Accelerator(
                            id = '', 
                            type = '', 
                            model = '', 
                            specs = daiedge_middleware_client.models.cpu_specs_item.CPUSpecsItem(
                                rate = , 
                                cores = , 
                                computing_power = , ), )
                        ], 
                    memory = daiedge_middleware_client.models.memory.Memory(
                        type = '', 
                        kind = '', 
                        specs = daiedge_middleware_client.models.default_specs_memory.DefaultSpecsMemory(
                            size = , 
                            rate = , ), ), 
                    storage = daiedge_middleware_client.models.storage.Storage(
                        type = '', 
                        specs = daiedge_middleware_client.models.storage_specs_item.StorageSpecsItem(
                            size = , 
                            rate = , ), ), 
                    power = daiedge_middleware_client.models.power.Power(
                        min = daiedge_middleware_client.models.power_item_details.PowerItemDetails(
                            value = 1.337, 
                            unit = '', ), 
                        max = daiedge_middleware_client.models.power_item_details.PowerItemDetails(
                            value = 1.337, 
                            unit = '', ), ), ),
                software_spec = daiedge_middleware_client.models.software_spec.SoftwareSpec(
                    os = '', 
                    version = '', 
                    engines = [
                        daiedge_middleware_client.models.engine.Engine(
                            id = '', 
                            name = '', 
                            family = '', 
                            version = '', 
                            computing_backends = [
                                ''
                                ], 
                            supported_applications = [
                                daiedge_middleware_client.models.supported_application.SupportedApplication(
                                    type = '', 
                                    details = daiedge_middleware_client.models.supported_application_details.SupportedApplicationDetails(
                                        supported_types = [
                                            ''
                                            ], ), )
                                ], )
                        ], ),
        )
        """

    def testUpdateHardwareBody(self):
        """Test UpdateHardwareBody"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    dAIEDGE-DLT

    API documentation

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from daiedge_middleware_client.models.register_benchmark_list import RegisterBenchmarkList

class TestRegisterBenchmarkList(unittest.TestCase):
    """RegisterBenchmarkList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RegisterBenchmarkList:
        """Test RegisterBenchmarkList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RegisterBenchmarkList`
        """
        model = RegisterBenchmarkList()
        if include_optional:
            return RegisterBenchmarkList(
                benchmarks = [
                    daiedge_middleware_client.models.register_benchmark_item.RegisterBenchmarkItem(
                        model_hash = '', 
                        dataset_hash = '', 
                        device_id = '', 
                        target = '', 
                        runtime = '', 
                        user_did = '', 
                        created = 1.337, 
                        zenodo_deposition_id = '', 
                        zenodo_doi = '', 
                        zenodo_file_url = '', 
                        report_hash = '', )
                    ],
                page = 1.337,
                total_pages = 1.337,
                total = 1.337
            )
        else:
            return RegisterBenchmarkList(
                benchmarks = [
                    daiedge_middleware_client.models.register_benchmark_item.RegisterBenchmarkItem(
                        model_hash = '', 
                        dataset_hash = '', 
                        device_id = '', 
                        target = '', 
                        runtime = '', 
                        user_did = '', 
                        created = 1.337, 
                        zenodo_deposition_id = '', 
                        zenodo_doi = '', 
                        zenodo_file_url = '', 
                        report_hash = '', )
                    ],
        )
        """

    def testRegisterBenchmarkList(self):
        """Test RegisterBenchmarkList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



"""
    dAIEDGE-DLT

    API documentation

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictFloat, StrictInt, StrictStr
from typing import Optional, Union
from typing_extensions import Annotated
from daiedge_middleware_client.models.accept_vc_request_body import AcceptVCRequestBody
from daiedge_middleware_client.models.decode_credential_body import DecodeCredentialBody
from daiedge_middleware_client.models.request_vc_body import RequestVCBody
from daiedge_middleware_client.models.user_vc_list import UserVCList
from daiedge_middleware_client.models.vc_request_list import VCRequestList
from daiedge_middleware_client.models.verify_credential_body import VerifyCredentialBody
from daiedge_middleware_client.models.verify_credential_response import VerifyCredentialResponse
from daiedge_middleware_client.models.verify_presentation_body import VerifyPresentationBody

from daiedge_middleware_client.api_client import ApiClient, RequestSerialized
from daiedge_middleware_client.api_response import ApiResponse
from daiedge_middleware_client.rest import RESTResponseType


class VcApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    async def vcs_active_id_post(
        self,
        id: Annotated[StrictStr, Field(description="VC ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """vcs_active_id_post

         Activates a verifiable credential Binding: ActiveVC

        :param id: VC ID (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._vcs_active_id_post_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def vcs_active_id_post_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="VC ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """vcs_active_id_post

         Activates a verifiable credential Binding: ActiveVC

        :param id: VC ID (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._vcs_active_id_post_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def vcs_active_id_post_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="VC ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """vcs_active_id_post

         Activates a verifiable credential Binding: ActiveVC

        :param id: VC ID (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._vcs_active_id_post_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _vcs_active_id_post_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'AuthToken'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/vcs/active/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def vcs_decode_credential_post(
        self,
        request: Annotated[Optional[DecodeCredentialBody], Field(description="Request body")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """vcs_decode_credential_post

         Decodes a verifiable credential JWT Binding: DecodeCredential

        :param request: Request body
        :type request: DecodeCredentialBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._vcs_decode_credential_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def vcs_decode_credential_post_with_http_info(
        self,
        request: Annotated[Optional[DecodeCredentialBody], Field(description="Request body")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """vcs_decode_credential_post

         Decodes a verifiable credential JWT Binding: DecodeCredential

        :param request: Request body
        :type request: DecodeCredentialBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._vcs_decode_credential_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def vcs_decode_credential_post_without_preload_content(
        self,
        request: Annotated[Optional[DecodeCredentialBody], Field(description="Request body")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """vcs_decode_credential_post

         Decodes a verifiable credential JWT Binding: DecodeCredential

        :param request: Request body
        :type request: DecodeCredentialBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._vcs_decode_credential_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _vcs_decode_credential_post_serialize(
        self,
        request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if request is not None:
            _body_params = request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'AuthToken'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/vcs/decode-credential',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def vcs_get(
        self,
        page: Annotated[Optional[Union[StrictFloat, StrictInt]], Field(description="Page. Starting by 1.")] = None,
        did: Annotated[Optional[StrictStr], Field(description="User DID")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> UserVCList:
        """vcs_get

         Lists user verifiable credentials Binding: ListUserVCs

        :param page: Page. Starting by 1.
        :type page: float
        :param did: User DID
        :type did: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._vcs_get_serialize(
            page=page,
            did=did,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UserVCList",
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def vcs_get_with_http_info(
        self,
        page: Annotated[Optional[Union[StrictFloat, StrictInt]], Field(description="Page. Starting by 1.")] = None,
        did: Annotated[Optional[StrictStr], Field(description="User DID")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[UserVCList]:
        """vcs_get

         Lists user verifiable credentials Binding: ListUserVCs

        :param page: Page. Starting by 1.
        :type page: float
        :param did: User DID
        :type did: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._vcs_get_serialize(
            page=page,
            did=did,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UserVCList",
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def vcs_get_without_preload_content(
        self,
        page: Annotated[Optional[Union[StrictFloat, StrictInt]], Field(description="Page. Starting by 1.")] = None,
        did: Annotated[Optional[StrictStr], Field(description="User DID")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """vcs_get

         Lists user verifiable credentials Binding: ListUserVCs

        :param page: Page. Starting by 1.
        :type page: float
        :param did: User DID
        :type did: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._vcs_get_serialize(
            page=page,
            did=did,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UserVCList",
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _vcs_get_serialize(
        self,
        page,
        did,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if page is not None:
            
            _query_params.append(('page', page))
            
        if did is not None:
            
            _query_params.append(('did', did))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'AuthToken'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/vcs',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def vcs_requests_get(
        self,
        page: Annotated[Optional[Union[StrictFloat, StrictInt]], Field(description="Page. Starting by 1.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> VCRequestList:
        """vcs_requests_get

         Lists verifiable credential requests Binding: ListVCRequests

        :param page: Page. Starting by 1.
        :type page: float
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._vcs_requests_get_serialize(
            page=page,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "VCRequestList",
            '403': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def vcs_requests_get_with_http_info(
        self,
        page: Annotated[Optional[Union[StrictFloat, StrictInt]], Field(description="Page. Starting by 1.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[VCRequestList]:
        """vcs_requests_get

         Lists verifiable credential requests Binding: ListVCRequests

        :param page: Page. Starting by 1.
        :type page: float
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._vcs_requests_get_serialize(
            page=page,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "VCRequestList",
            '403': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def vcs_requests_get_without_preload_content(
        self,
        page: Annotated[Optional[Union[StrictFloat, StrictInt]], Field(description="Page. Starting by 1.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """vcs_requests_get

         Lists verifiable credential requests Binding: ListVCRequests

        :param page: Page. Starting by 1.
        :type page: float
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._vcs_requests_get_serialize(
            page=page,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "VCRequestList",
            '403': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _vcs_requests_get_serialize(
        self,
        page,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if page is not None:
            
            _query_params.append(('page', page))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'AuthToken'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/vcs/requests',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def vcs_requests_id_accept_post(
        self,
        id: Annotated[StrictStr, Field(description="VC Request ID")],
        request: Annotated[Optional[AcceptVCRequestBody], Field(description="Request body")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """vcs_requests_id_accept_post

         Accepts a verifiable credential request Binding: AcceptVCRequest

        :param id: VC Request ID (required)
        :type id: str
        :param request: Request body
        :type request: AcceptVCRequestBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._vcs_requests_id_accept_post_serialize(
            id=id,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def vcs_requests_id_accept_post_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="VC Request ID")],
        request: Annotated[Optional[AcceptVCRequestBody], Field(description="Request body")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """vcs_requests_id_accept_post

         Accepts a verifiable credential request Binding: AcceptVCRequest

        :param id: VC Request ID (required)
        :type id: str
        :param request: Request body
        :type request: AcceptVCRequestBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._vcs_requests_id_accept_post_serialize(
            id=id,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def vcs_requests_id_accept_post_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="VC Request ID")],
        request: Annotated[Optional[AcceptVCRequestBody], Field(description="Request body")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """vcs_requests_id_accept_post

         Accepts a verifiable credential request Binding: AcceptVCRequest

        :param id: VC Request ID (required)
        :type id: str
        :param request: Request body
        :type request: AcceptVCRequestBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._vcs_requests_id_accept_post_serialize(
            id=id,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _vcs_requests_id_accept_post_serialize(
        self,
        id,
        request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if request is not None:
            _body_params = request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'AuthToken'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/vcs/requests/{id}/accept',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def vcs_requests_post(
        self,
        request: Annotated[Optional[RequestVCBody], Field(description="Request body")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """vcs_requests_post

         Requests a verifiable credential Binding: RequestVC

        :param request: Request body
        :type request: RequestVCBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._vcs_requests_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def vcs_requests_post_with_http_info(
        self,
        request: Annotated[Optional[RequestVCBody], Field(description="Request body")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """vcs_requests_post

         Requests a verifiable credential Binding: RequestVC

        :param request: Request body
        :type request: RequestVCBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._vcs_requests_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def vcs_requests_post_without_preload_content(
        self,
        request: Annotated[Optional[RequestVCBody], Field(description="Request body")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """vcs_requests_post

         Requests a verifiable credential Binding: RequestVC

        :param request: Request body
        :type request: RequestVCBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._vcs_requests_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _vcs_requests_post_serialize(
        self,
        request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if request is not None:
            _body_params = request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'AuthToken'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/vcs/requests',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def vcs_revoke_id_post(
        self,
        id: Annotated[StrictStr, Field(description="VC ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """vcs_revoke_id_post

         Revokes a verifiable credential Binding: RevokeVC

        :param id: VC ID (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._vcs_revoke_id_post_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def vcs_revoke_id_post_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="VC ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """vcs_revoke_id_post

         Revokes a verifiable credential Binding: RevokeVC

        :param id: VC ID (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._vcs_revoke_id_post_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def vcs_revoke_id_post_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="VC ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """vcs_revoke_id_post

         Revokes a verifiable credential Binding: RevokeVC

        :param id: VC ID (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._vcs_revoke_id_post_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _vcs_revoke_id_post_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'AuthToken'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/vcs/revoke/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def vcs_verify_credential_post(
        self,
        request: Annotated[Optional[VerifyCredentialBody], Field(description="Request body")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> VerifyCredentialResponse:
        """vcs_verify_credential_post

         Verifies a verifiable credential Binding: VerifyCredential

        :param request: Request body
        :type request: VerifyCredentialBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._vcs_verify_credential_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "VerifyCredentialResponse",
            '400': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def vcs_verify_credential_post_with_http_info(
        self,
        request: Annotated[Optional[VerifyCredentialBody], Field(description="Request body")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[VerifyCredentialResponse]:
        """vcs_verify_credential_post

         Verifies a verifiable credential Binding: VerifyCredential

        :param request: Request body
        :type request: VerifyCredentialBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._vcs_verify_credential_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "VerifyCredentialResponse",
            '400': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def vcs_verify_credential_post_without_preload_content(
        self,
        request: Annotated[Optional[VerifyCredentialBody], Field(description="Request body")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """vcs_verify_credential_post

         Verifies a verifiable credential Binding: VerifyCredential

        :param request: Request body
        :type request: VerifyCredentialBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._vcs_verify_credential_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "VerifyCredentialResponse",
            '400': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _vcs_verify_credential_post_serialize(
        self,
        request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if request is not None:
            _body_params = request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'AuthToken'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/vcs/verify-credential',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    async def vcs_verify_presentation_post(
        self,
        request: Annotated[Optional[VerifyPresentationBody], Field(description="Request body")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """vcs_verify_presentation_post

         Verifies a verifiable presentation Binding: VerifyPresentation

        :param request: Request body
        :type request: VerifyPresentationBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._vcs_verify_presentation_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def vcs_verify_presentation_post_with_http_info(
        self,
        request: Annotated[Optional[VerifyPresentationBody], Field(description="Request body")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """vcs_verify_presentation_post

         Verifies a verifiable presentation Binding: VerifyPresentation

        :param request: Request body
        :type request: VerifyPresentationBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._vcs_verify_presentation_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def vcs_verify_presentation_post_without_preload_content(
        self,
        request: Annotated[Optional[VerifyPresentationBody], Field(description="Request body")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """vcs_verify_presentation_post

         Verifies a verifiable presentation Binding: VerifyPresentation

        :param request: Request body
        :type request: VerifyPresentationBody
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._vcs_verify_presentation_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _vcs_verify_presentation_post_serialize(
        self,
        request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if request is not None:
            _body_params = request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'AuthToken'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/vcs/verify-presentation',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

# flake8: noqa
"""
    dAIEDGE-DLT

    API documentation

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from daiedge_middleware_client.models.accelerator import Accelerator
from daiedge_middleware_client.models.accept_vc_request_body import AcceptVCRequestBody
from daiedge_middleware_client.models.add_delegate_body import AddDelegateBody
from daiedge_middleware_client.models.authentication_context import AuthenticationContext
from daiedge_middleware_client.models.authentication_context_error import AuthenticationContextError
from daiedge_middleware_client.models.buy_resource_body import BuyResourceBody
from daiedge_middleware_client.models.cpu import CPU
from daiedge_middleware_client.models.cpu_specs_item import CPUSpecsItem
from daiedge_middleware_client.models.change_owner_body import ChangeOwnerBody
from daiedge_middleware_client.models.check_access_response import CheckAccessResponse
from daiedge_middleware_client.models.cost import Cost
from daiedge_middleware_client.models.create_ai_model_response import CreateAIModelResponse
from daiedge_middleware_client.models.create_benchmark_response import CreateBenchmarkResponse
from daiedge_middleware_client.models.create_did_policy_body import CreateDIDPolicyBody
from daiedge_middleware_client.models.create_dataset_response import CreateDatasetResponse
from daiedge_middleware_client.models.create_hardware_policy_body import CreateHardwarePolicyBody
from daiedge_middleware_client.models.create_hardware_response import CreateHardwareResponse
from daiedge_middleware_client.models.create_role_body import CreateRoleBody
from daiedge_middleware_client.models.create_role_response import CreateRoleResponse
from daiedge_middleware_client.models.decode_credential_body import DecodeCredentialBody
from daiedge_middleware_client.models.default_spec_item import DefaultSpecItem
from daiedge_middleware_client.models.default_specs_memory import DefaultSpecsMemory
from daiedge_middleware_client.models.delete_hardware_body import DeleteHardwareBody
from daiedge_middleware_client.models.edit_did_policy_body import EditDIDPolicyBody
from daiedge_middleware_client.models.edit_hardware_policy_body import EditHardwarePolicyBody
from daiedge_middleware_client.models.engine import Engine
from daiedge_middleware_client.models.error_response import ErrorResponse
from daiedge_middleware_client.models.generate_key_pair_body import GenerateKeyPairBody
from daiedge_middleware_client.models.get_register_ai_model_item import GetRegisterAIModelItem
from daiedge_middleware_client.models.get_register_benchmark_item import GetRegisterBenchmarkItem
from daiedge_middleware_client.models.get_register_dataset_item import GetRegisterDatasetItem
from daiedge_middleware_client.models.get_register_hardware_item import GetRegisterHardwareItem
from daiedge_middleware_client.models.get_reward_by_rule import GetRewardByRule
from daiedge_middleware_client.models.gran_role_body import GranRoleBody
from daiedge_middleware_client.models.grant_access_body import GrantAccessBody
from daiedge_middleware_client.models.grant_revoke_issuer_role_body import GrantRevokeIssuerRoleBody
from daiedge_middleware_client.models.hardware_access_item import HardwareAccessItem
from daiedge_middleware_client.models.hardware_access_list import HardwareAccessList
from daiedge_middleware_client.models.hardware_policy_response import HardwarePolicyResponse
from daiedge_middleware_client.models.hardware_spec import HardwareSpec
from daiedge_middleware_client.models.has_role_response import HasRoleResponse
from daiedge_middleware_client.models.identity_owner_response import IdentityOwnerResponse
from daiedge_middleware_client.models.license_request_item import LicenseRequestItem
from daiedge_middleware_client.models.license_request_list import LicenseRequestList
from daiedge_middleware_client.models.listed_resource_item import ListedResourceItem
from daiedge_middleware_client.models.listed_resource_list import ListedResourceList
from daiedge_middleware_client.models.login_error_bad_request import LoginErrorBadRequest
from daiedge_middleware_client.models.login_error_forbidden import LoginErrorForbidden
from daiedge_middleware_client.models.login_request import LoginRequest
from daiedge_middleware_client.models.login_response import LoginResponse
from daiedge_middleware_client.models.memory import Memory
from daiedge_middleware_client.models.mint_tokens_body import MintTokensBody
from daiedge_middleware_client.models.pause_contract_body import PauseContractBody
from daiedge_middleware_client.models.pause_system_body import PauseSystemBody
from daiedge_middleware_client.models.power import Power
from daiedge_middleware_client.models.power_item_details import PowerItemDetails
from daiedge_middleware_client.models.register_ai_model_body import RegisterAIModelBody
from daiedge_middleware_client.models.register_ai_model_item import RegisterAIModelItem
from daiedge_middleware_client.models.register_ai_model_list import RegisterAIModelList
from daiedge_middleware_client.models.register_access_body import RegisterAccessBody
from daiedge_middleware_client.models.register_benchmark_body import RegisterBenchmarkBody
from daiedge_middleware_client.models.register_benchmark_item import RegisterBenchmarkItem
from daiedge_middleware_client.models.register_benchmark_list import RegisterBenchmarkList
from daiedge_middleware_client.models.register_data_set_item import RegisterDataSetItem
from daiedge_middleware_client.models.register_data_set_list import RegisterDataSetList
from daiedge_middleware_client.models.register_dataset_body import RegisterDatasetBody
from daiedge_middleware_client.models.register_hardware_body import RegisterHardwareBody
from daiedge_middleware_client.models.register_hardware_item import RegisterHardwareItem
from daiedge_middleware_client.models.register_hardware_list import RegisterHardwareList
from daiedge_middleware_client.models.remove_did_policy_body import RemoveDIDPolicyBody
from daiedge_middleware_client.models.remove_hardware_policy_body import RemoveHardwarePolicyBody
from daiedge_middleware_client.models.remove_listed_resource_body import RemoveListedResourceBody
from daiedge_middleware_client.models.remove_reward_rule_body import RemoveRewardRuleBody
from daiedge_middleware_client.models.request_user_license_body import RequestUserLicenseBody
from daiedge_middleware_client.models.request_vc_body import RequestVCBody
from daiedge_middleware_client.models.revoke_access_body import RevokeAccessBody
from daiedge_middleware_client.models.revoke_delegate_body import RevokeDelegateBody
from daiedge_middleware_client.models.revoke_issuer_role_body import RevokeIssuerRoleBody
from daiedge_middleware_client.models.revoke_license_body import RevokeLicenseBody
from daiedge_middleware_client.models.revoke_role_body import RevokeRoleBody
from daiedge_middleware_client.models.reward_history_item import RewardHistoryItem
from daiedge_middleware_client.models.reward_history_list import RewardHistoryList
from daiedge_middleware_client.models.reward_manual_body import RewardManualBody
from daiedge_middleware_client.models.reward_off_chain_body import RewardOffChainBody
from daiedge_middleware_client.models.reward_on_chain_body import RewardOnChainBody
from daiedge_middleware_client.models.role_management_item import RoleManagementItem
from daiedge_middleware_client.models.role_management_list import RoleManagementList
from daiedge_middleware_client.models.sell_resource_body import SellResourceBody
from daiedge_middleware_client.models.set_benchmark_result_body import SetBenchmarkResultBody
from daiedge_middleware_client.models.set_hardware_body import SetHardwareBody
from daiedge_middleware_client.models.set_reward_rule_body import SetRewardRuleBody
from daiedge_middleware_client.models.signup_error_bad_request import SignupErrorBadRequest
from daiedge_middleware_client.models.signup_request import SignupRequest
from daiedge_middleware_client.models.signup_response import SignupResponse
from daiedge_middleware_client.models.software_spec import SoftwareSpec
from daiedge_middleware_client.models.storage import Storage
from daiedge_middleware_client.models.storage_specs_item import StorageSpecsItem
from daiedge_middleware_client.models.supported_application import SupportedApplication
from daiedge_middleware_client.models.supported_application_details import SupportedApplicationDetails
from daiedge_middleware_client.models.system_status import SystemStatus
from daiedge_middleware_client.models.unpause_contract_body import UnpauseContractBody
from daiedge_middleware_client.models.unpause_system_body import UnpauseSystemBody
from daiedge_middleware_client.models.update_ai_model_body import UpdateAIModelBody
from daiedge_middleware_client.models.update_dataset_body import UpdateDatasetBody
from daiedge_middleware_client.models.update_hardware_body import UpdateHardwareBody
from daiedge_middleware_client.models.use_license_item import UseLicenseItem
from daiedge_middleware_client.models.user_did_item import UserDIDItem
from daiedge_middleware_client.models.user_did_list import UserDIDList
from daiedge_middleware_client.models.user_did_resolve_response import UserDIDResolveResponse
from daiedge_middleware_client.models.user_license_list import UserLicenseList
from daiedge_middleware_client.models.user_vc_item import UserVCItem
from daiedge_middleware_client.models.user_vc_list import UserVCList
from daiedge_middleware_client.models.vc_claim import VCClaim
from daiedge_middleware_client.models.vc_request_item import VCRequestItem
from daiedge_middleware_client.models.vc_request_list import VCRequestList
from daiedge_middleware_client.models.validate_license_request_body import ValidateLicenseRequestBody
from daiedge_middleware_client.models.verify_credential_body import VerifyCredentialBody
from daiedge_middleware_client.models.verify_credential_response import VerifyCredentialResponse
from daiedge_middleware_client.models.verify_presentation_body import VerifyPresentationBody
from daiedge_middleware_client.models.wallet_change_password_bad_request import WalletChangePasswordBadRequest
from daiedge_middleware_client.models.wallet_change_password_body import WalletChangePasswordBody
from daiedge_middleware_client.models.wallet_create_bad_request import WalletCreateBadRequest
from daiedge_middleware_client.models.wallet_create_body import WalletCreateBody
from daiedge_middleware_client.models.wallet_edit_bad_request import WalletEditBadRequest
from daiedge_middleware_client.models.wallet_edit_body import WalletEditBody
from daiedge_middleware_client.models.wallet_export_bad_request import WalletExportBadRequest
from daiedge_middleware_client.models.wallet_export_body import WalletExportBody
from daiedge_middleware_client.models.wallet_export_response import WalletExportResponse
from daiedge_middleware_client.models.wallet_info import WalletInfo




"""
    dAIEDGE-DLT

    API documentation

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictStr
from typing import Optional
from typing_extensions import Annotated
from daiedge_middleware_client.models.mint_tokens_body import MintTokensBody

from daiedge_middleware_client.api_client import ApiClient, RequestSerialized
from daiedge_middleware_client.api_response import ApiResponse
from daiedge_middleware_client.rest import RESTResponseType


class TokensApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    async def tokens_balance_get(
        self,
        did: Annotated[StrictStr, Field(description="User DID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> int:
        """tokens_balance_get

         Gets identity balance Binding: GetBalance

        :param did: User DID (required)
        :type did: str
        :return: Returns the token balance as an integer.
        """ # noqa: E501

        _param = self._tokens_balance_get_serialize(
            did=did,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        # FIX: The API returns a plain integer, not a typed object.
        # The auto-generated client maps '200': None which discards the body.
        # We must call response_data.read() first, then read from response.
        await response_data.read()
        return json.loads(response_data.data)


    @validate_call
    async def tokens_balance_get_with_http_info(
        self,
        did: Annotated[StrictStr, Field(description="User DID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[int]:
        """tokens_balance_get

         Gets identity balance Binding: GetBalance

        :param did: User DID (required)
        :type did: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._tokens_balance_get_serialize(
            did=did,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def tokens_balance_get_without_preload_content(
        self,
        did: Annotated[StrictStr, Field(description="User DID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """tokens_balance_get

         Gets identity balance Binding: GetBalance

        :param did: User DID (required)
        :type did: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._tokens_balance_get_serialize(
            did=did,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _tokens_balance_get_serialize(
        self,
        did,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        if did is not None:
            _query_params.append(('did', did))

        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        _auth_settings: List[str] = [
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/tokens/balance',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )


    @validate_call
    async def tokens_mint_post(
        self,
        request: Annotated[Optional[MintTokensBody], Field(description="Request body")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """tokens_mint_post

         Mints tokens Binding: MintTokens

        :param request: Request body
        :type request: MintTokensBody
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._tokens_mint_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    async def tokens_mint_post_with_http_info(
        self,
        request: Annotated[Optional[MintTokensBody], Field(description="Request body")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """tokens_mint_post

         Mints tokens Binding: MintTokens

        :param request: Request body
        :type request: MintTokensBody
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._tokens_mint_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    async def tokens_mint_post_without_preload_content(
        self,
        request: Annotated[Optional[MintTokensBody], Field(description="Request body")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """tokens_mint_post

         Mints tokens Binding: MintTokens

        :param request: Request body
        :type request: MintTokensBody
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._tokens_mint_post_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
            '400': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = await self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _tokens_mint_post_serialize(
        self,
        request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        if request is not None:
            _body_params = request

        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        _auth_settings: List[str] = [
            'AuthToken'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/tokens/mint',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )


# coding: utf-8

"""
    dAIEDGE-DLT

    API documentation

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from daiedge_middleware_client.api.reward_manager_api import RewardManagerApi


class TestRewardManagerApi(unittest.IsolatedAsyncioTestCase):
    """RewardManagerApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = RewardManagerApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_rewards_get(self) -> None:
        """Test case for rewards_get

        """
        pass

    async def test_rewards_get_reward_by_rule_aid_get(self) -> None:
        """Test case for rewards_get_reward_by_rule_aid_get

        """
        pass

    async def test_rewards_remove_reward_rule_post(self) -> None:
        """Test case for rewards_remove_reward_rule_post

        """
        pass

    async def test_rewards_reward_manual_post(self) -> None:
        """Test case for rewards_reward_manual_post

        """
        pass

    async def test_rewards_reward_off_chain_post(self) -> None:
        """Test case for rewards_reward_off_chain_post

        """
        pass

    async def test_rewards_reward_on_chain_post(self) -> None:
        """Test case for rewards_reward_on_chain_post

        """
        pass

    async def test_rewards_set_reward_rule_post(self) -> None:
        """Test case for rewards_set_reward_rule_post

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    dAIEDGE-DLT

    API documentation

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class UseLicenseItem(BaseModel):
    """
    UseLicenseItem
    """ # noqa: E501
    id: StrictStr = Field(description="License ID")
    uid: StrictStr = Field(description="User ID")
    did: StrictStr = Field(description="Device ID")
    hid: StrictStr = Field(description="Hardware ID")
    license: Dict[str, Any] = Field(description="License")
    created: Union[StrictFloat, StrictInt] = Field(description="Created timestamp")
    is_valid: Optional[StrictBool] = Field(default=None, description="True if the license is valid on blockchain", alias="isValid")
    expiration_time: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="License expiration time (timestamp in ms)", alias="expirationTime")
    type1: Optional[StrictBool] = Field(default=None, description="True if the license includes type1 usage")
    type2: Optional[StrictBool] = Field(default=None, description="True if the license includes type2 usage")
    type3: Optional[StrictBool] = Field(default=None, description="True if the license includes type3 usage")
    single_use: Optional[StrictBool] = Field(default=None, description="True if the license is single-use", alias="singleUse")
    __properties: ClassVar[List[str]] = ["id", "uid", "did", "hid", "license", "created", "isValid", "expirationTime", "type1", "type2", "type3", "singleUse"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UseLicenseItem from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UseLicenseItem from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "uid": obj.get("uid"),
            "did": obj.get("did"),
            "hid": obj.get("hid"),
            "license": obj.get("license"),
            "created": obj.get("created"),
            "isValid": obj.get("isValid"),
            "expirationTime": obj.get("expirationTime"),
            "type1": obj.get("type1"),
            "type2": obj.get("type2"),
            "type3": obj.get("type3"),
            "singleUse": obj.get("singleUse")
        })
        return _obj





# coding: utf-8

"""
    dAIEDGE-DLT

    API documentation

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from daiedge_middleware_client.models.revoke_access_body import RevokeAccessBody

class TestRevokeAccessBody(unittest.TestCase):
    """RevokeAccessBody unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RevokeAccessBody:
        """Test RevokeAccessBody
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RevokeAccessBody`
        """
        model = RevokeAccessBody()
        if include_optional:
            return RevokeAccessBody(
                wallet_id = '',
                password = '',
                user_did = '',
                did = '',
                resource_id = '',
                resource_type = 'ai_model'
            )
        else:
            return RevokeAccessBody(
                wallet_id = '',
                password = '',
                user_did = '',
                did = '',
                resource_id = '',
                resource_type = 'ai_model',
        )
        """

    def testRevokeAccessBody(self):
        """Test RevokeAccessBody"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
